/*= GM SSP Konstanter Include File ==========================================*/

#ifndef __GMPSP_HEADER
#define __GMPSP_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE        (_VI_ERROR+0x3FFC0803L)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                     (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define GMPSP_ERROR_INSTRUMENT_ERROR                (VI_ERROR_INSTR_OFFSET + 0xF0L)

    
#define GMPSP_WARNING_SMALL_BUFFER                  (VI_WARNING_INSTR_OFFSET + 0xF1L)

/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/
#define GMPSP_MIN 0
#define GMPSP_MAX 1

#define GMPSP_TRIGGER_OFF    0
#define GMPSP_TRIGGER_OUT    1
#define GMPSP_TRIGGER_SQS    2
#define GMPSP_TRIGGER_SEQ    3
#define GMPSP_TRIGGER_LOC    4
#define GMPSP_TRIGGER_MINMAX 5
#define GMPSP_TRIGGER_AIX    6
#define GMPSP_TRIGGER_AIU    7
#define GMPSP_TRIGGER_AII    8
    
#define GMPSP_SIGNAL_OFF  0
#define GMPSP_SIGNAL_ON   1
#define GMPSP_SIGNAL_OUT  2
#define GMPSP_SIGNAL_MODE 3
#define GMPSP_SIGNAL_SEQ  4
#define GMPSP_SIGNAL_SSET 5
#define GMPSP_SIGNAL_ULOW 6
#define GMPSP_SIGNAL_UHIG 7
#define GMPSP_SIGNAL_ILOW 8
#define GMPSP_SIGNAL_IHIG 9
    
#define GMPSP_RESET  0
#define GMPSP_RECALL 1
#define GMPSP_SBY    2

#define GMPSP_DISPLAY_OFF  0
#define GMPSP_DISPLAY_UOUT 1
#define GMPSP_DISPLAY_USET 2
#define GMPSP_DISPLAY_PSET 3
#define GMPSP_DISPLAY_IOUT 1
#define GMPSP_DISPLAY_ISET 2
#define GMPSP_DISPLAY_POUT 3
    
#define GMPSP_FILTER_1MS   1
#define GMPSP_FILTER_10MS  2
#define GMPSP_FILTER_50MS  3
#define GMPSP_FILTER_400MS 4
    
#define GMPSP_CONSTANT_R 0
#define GMPSP_CONSTANT_L 1

#define GMPSP_SEQFUNC_CLR  0
#define GMPSP_SEQFUNC_NF   1
#define GMPSP_SEQFUNC_RU   2
#define GMPSP_SEQFUNC_RI   3
#define GMPSP_SEQFUNC_SOFF 4
#define GMPSP_SEQFUNC_SON  5
#define GMPSP_SEQFUNC_AUOF 6
#define GMPSP_SEQFUNC_AUON 7
#define GMPSP_SEQFUNC_AUSS 8
#define GMPSP_SEQFUNC_AIOF 9
#define GMPSP_SEQFUNC_AION 10
#define GMPSP_SEQFUNC_AISS 11
#define GMPSP_SEQFUNC_R01  12
#define GMPSP_SEQFUNC_R02  13
#define GMPSP_SEQFUNC_R03  14
#define GMPSP_SEQFUNC_R04  15
#define GMPSP_SEQFUNC_R05  16
#define GMPSP_SEQFUNC_R06  17
#define GMPSP_SEQFUNC_R07  18
#define GMPSP_SEQFUNC_R08  19
#define GMPSP_SEQFUNC_R09  20
#define GMPSP_SEQFUNC_R10  21
#define GMPSP_SEQFUNC_R11  22
#define GMPSP_SEQFUNC_R12  23
#define GMPSP_SEQFUNC_S01  12
#define GMPSP_SEQFUNC_S02  13
#define GMPSP_SEQFUNC_S03  14
#define GMPSP_SEQFUNC_S04  15
#define GMPSP_SEQFUNC_S05  16
#define GMPSP_SEQFUNC_S06  17
#define GMPSP_SEQFUNC_S07  18
#define GMPSP_SEQFUNC_S08  19
#define GMPSP_SEQFUNC_S09  20
#define GMPSP_SEQFUNC_S10  21
#define GMPSP_SEQFUNC_S11  22
#define GMPSP_SEQFUNC_S12  23
    
#define GMPSP_SEQTRIG_GO    0
#define GMPSP_SEQTRIG_START 1
#define GMPSP_SEQTRIG_STOP  2
#define GMPSP_SEQTRIG_STEP  3
#define GMPSP_SEQTRIG_HOLD  4    
    
#define GMPSP_REG_A 0
#define GMPSP_REG_B 1
#define GMPSP_REG_C 2
#define GMPSP_REG_A_EVENT 3
#define GMPSP_REG_B_EVENT 4
#define GMPSP_REG_C_EVENT 5
#define GMPSP_REG_A_COND  6
#define GMPSP_REG_B_COND  7
    
#define GMPSP_ANALOG_OFF  0
#define GMPSP_ANALOG_ON   1
#define GMPSP_ANALOG_SSET 2


ViStatus _VI_FUNC gmpsp_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViSession *instrumentHandle);

ViStatus _VI_FUNC gmpsp_ConfigureVoltage (ViSession instrumentHandle,
                                          ViReal64 setVoltage,
                                          ViReal64 voltageLimitLow,
                                          ViReal64 voltageLimitHigh);

ViStatus _VI_FUNC gmpsp_ConfigureOvervoltageProtection (ViSession instrumentHandle,
                                                        ViBoolean OVPState,
                                                        ViReal64 OVPLevel,
                                                        ViReal64 OVPDelay);

ViStatus _VI_FUNC gmpsp_SetVoltageValue (ViSession instrumentHandle,
                                         ViReal64 setVoltage);

ViStatus _VI_FUNC gmpsp_GetVoltageValue (ViSession instrumentHandle,
                                         ViReal64 *setVoltage);

ViStatus _VI_FUNC gmpsp_SetVoltageLimitValue (ViSession instrumentHandle,
                                              ViInt32 limitType,
                                              ViReal64 voltageValue);

ViStatus _VI_FUNC gmpsp_GetVoltageLimitValue (ViSession instrumentHandle,
                                              ViInt32 limitType,
                                              ViReal64 *voltageValue);

ViStatus _VI_FUNC gmpsp_SetOvervoltageProtectionState (ViSession instrumentHandle,
                                                       ViBoolean OVPState);

ViStatus _VI_FUNC gmpsp_GetOvervoltageProtectionState (ViSession instrumentHandle,
                                                       ViBoolean *OVPState);

ViStatus _VI_FUNC gmpsp_SetOvervoltageProtectionValue (ViSession instrumentHandle,
                                                       ViReal64 OVPLevel);

ViStatus _VI_FUNC gmpsp_GetOvervoltageProtectionValue (ViSession instrumentHandle,
                                                       ViReal64 *OVPLevel);

ViStatus _VI_FUNC gmpsp_SetOvervoltageProtectionDelay (ViSession instrumentHandle,
                                                       ViReal64 OVPDelay);

ViStatus _VI_FUNC gmpsp_GetOvervoltageProtectionDelay (ViSession instrumentHandle,
                                                       ViReal64 *OVPDelay);

ViStatus _VI_FUNC gmpsp_ConfigureCurrent (ViSession instrumentHandle,
                                          ViReal64 setCurrent,
                                          ViReal64 currentLimitLow,
                                          ViReal64 currentLimitHigh);

ViStatus _VI_FUNC gmpsp_ConfigureOvercurrentProtection (ViSession instrumentHandle,
                                                        ViBoolean OCPState,
                                                        ViReal64 OCPLevel,
                                                        ViReal64 OCPDelay);

ViStatus _VI_FUNC gmpsp_SetCurrentValue (ViSession instrumentHandle,
                                         ViReal64 setCurrent);

ViStatus _VI_FUNC gmpsp_GetCurrentValue (ViSession instrumentHandle,
                                         ViReal64 *setCurrent);

ViStatus _VI_FUNC gmpsp_SetCurrentLimitValue (ViSession instrumentHandle,
                                              ViInt32 limitType,
                                              ViReal64 currentValue);

ViStatus _VI_FUNC gmpsp_GetCurrentLimitValue (ViSession instrumentHandle,
                                              ViInt32 limitType,
                                              ViReal64 *currentValue);

ViStatus _VI_FUNC gmpsp_SetOvercurrentProtectionState (ViSession instrumentHandle,
                                                       ViBoolean OCPState);

ViStatus _VI_FUNC gmpsp_GetOvercurrentProtectionState (ViSession instrumentHandle,
                                                       ViBoolean *OCPState);

ViStatus _VI_FUNC gmpsp_SetOvercurrentProtectionValue (ViSession instrumentHandle,
                                                       ViReal64 OCPLevel);

ViStatus _VI_FUNC gmpsp_GetOvercurrentProtectionValue (ViSession instrumentHandle,
                                                       ViReal64 *OCPLevel);

ViStatus _VI_FUNC gmpsp_SetOvercurrentProtectionDelay (ViSession instrumentHandle,
                                                       ViReal64 OCPDelay);

ViStatus _VI_FUNC gmpsp_GetOvercurrentProtectionDelay (ViSession instrumentHandle,
                                                       ViReal64 *OCPDelay);

ViStatus _VI_FUNC gmpsp_SetPowerValue (ViSession instrumentHandle,
                                       ViReal64 setPower);

ViStatus _VI_FUNC gmpsp_GetPowerValue (ViSession instrumentHandle,
                                       ViReal64 *setPower);

ViStatus _VI_FUNC gmpsp_ConfigureOutputState (ViSession instrumentHandle,
                                              ViBoolean outputState);

ViStatus _VI_FUNC gmpsp_GetOutputState (ViSession instrumentHandle,
                                            ViBoolean *outputState);

ViStatus _VI_FUNC gmpsp_GetOutputMode (ViSession instrumentHandle,
                                           ViInt32 *outputMode);

ViStatus _VI_FUNC gmpsp_ConfigureTriggerMode (ViSession instrumentHandle,
                                              ViInt32 triggerMode1,
                                              ViInt32 triggerMode2);

ViStatus _VI_FUNC gmpsp_ConfigureSignalFunction (ViSession instrumentHandle,
                                                 ViInt32 signal1,
                                                 ViInt32 signal2,
                                                 ViInt32 signal3);

ViStatus _VI_FUNC gmpsp_ConfigureSignalOutputState (ViSession instrumentHandle,
                                                    ViInt32 u_ext, ViInt32 i_ext,
                                                    ViBoolean SSet);

ViStatus _VI_FUNC gmpsp_GetTriggerMode (ViSession instrumentHandle,
                                        ViInt32 *triggerMode1,
                                        ViInt32 *triggerMode2);

ViStatus _VI_FUNC gmpsp_GetSignalFunction (ViSession instrumentHandle,
                                           ViInt32 *signal1, ViInt32 *signal2,
                                           ViInt32 *signal3);

ViStatus _VI_FUNC gmpsp_SetSset (ViSession instrumentHandle, ViBoolean SSet);

ViStatus _VI_FUNC gmpsp_GetSset (ViSession instrumentHandle, ViBoolean *SSet);

ViStatus _VI_FUNC gmpsp_SetAnalogInterfaceState (ViSession instrumentHandle,
                                                 ViInt32 u_ext, ViInt32 i_ext);

ViStatus _VI_FUNC gmpsp_GetAnalogInterfaceState (ViSession instrumentHandle,
                                                 ViInt32 *u_ext, ViInt32 *i_ext);

ViStatus _VI_FUNC gmpsp_ConfigureMinMax (ViSession instrumentHandle,
                                         ViBoolean minMaxState,
                                         ViReal64 minVoltage,
                                         ViReal64 maxVoltage,
                                         ViReal64 minCurrent,
                                         ViReal64 maxCurrent);

ViStatus _VI_FUNC gmpsp_SetMinMaxState (ViSession instrumentHandle,
                                        ViBoolean minMaxState);

ViStatus _VI_FUNC gmpsp_GetMinMaxState (ViSession instrumentHandle,
                                        ViBoolean *minMaxState);

ViStatus _VI_FUNC gmpsp_SetMinMaxValues (ViSession instrumentHandle,
                                         ViReal64 minVoltage,
                                         ViReal64 maxVoltage,
                                         ViReal64 minCurrent,
                                         ViReal64 maxCurrent);

ViStatus _VI_FUNC gmpsp_GetMinMaxValues (ViSession instrumentHandle,
                                         ViReal64 *minVoltage,
                                         ViReal64 *maxVoltage,
                                         ViReal64 *minCurrent,
                                         ViReal64 *maxCurrent);

ViStatus _VI_FUNC gmpsp_SetPwrOnMode (ViSession instrumentHandle,
                                      ViInt32 powerOnMode);

ViStatus _VI_FUNC gmpsp_GetPwrOnMode (ViSession instrumentHandle,
                                      ViInt32 *powerOnMode);

ViStatus _VI_FUNC gmpsp_SetDisplayFunction (ViSession instrumentHandle,
                                            ViInt32 displayA, ViInt32 displayB);

ViStatus _VI_FUNC gmpsp_GetDisplayFunction (ViSession instrumentHandle,
                                            ViInt32 *displayA, ViInt32 *displayB);

ViStatus _VI_FUNC gmpsp_SetMeasurementFilter (ViSession instrumentHandle,
                                              ViInt32 filter);

ViStatus _VI_FUNC gmpsp_GetMeasurementFilter (ViSession instrumentHandle,
                                              ViInt32 *filter);

ViStatus _VI_FUNC gmpsp_SetInternalSinkState (ViSession instrumentHandle,
                                              ViBoolean internalSinkState);

ViStatus _VI_FUNC gmpsp_GetInternalSinkState (ViSession instrumentHandle,
                                              ViBoolean *internalSinkState);

ViStatus _VI_FUNC gmpsp_SetConstantCurrentRegulation (ViSession instrumentHandle,
                                                      ViInt32 regulation);

ViStatus _VI_FUNC gmpsp_GetConstantCurrentRegulation (ViSession instrumentHandle,
                                                      ViInt32 *regulation);

ViStatus _VI_FUNC gmpsp_ConfigureSeqSettings (ViSession instrumentHandle,
                                              ViInt32 startIndex,
                                              ViInt32 stopIndex,
                                              ViInt32 sequenceRepetition,
                                              ViReal64 defaultTime);

ViStatus _VI_FUNC gmpsp_ConfigureSeqStep (ViSession instrumentHandle,
                                          ViInt32 storageNumber,
                                          ViReal64 setVoltage,
                                          ViReal64 setCurrent, ViReal64 setTime,
                                          ViInt32 setFunction);

ViStatus _VI_FUNC gmpsp_SetSeqRange (ViSession instrumentHandle,
                                     ViInt32 startIndex, ViInt32 stopIndex);

ViStatus _VI_FUNC gmpsp_GetSeqRange (ViSession instrumentHandle,
                                     ViInt32 *startIndex, ViInt32 *stopIndex);

ViStatus _VI_FUNC gmpsp_SetSeqRepetition (ViSession instrumentHandle,
                                          ViInt32 sequenceRepetition);

ViStatus _VI_FUNC gmpsp_GetSeqRepetition (ViSession instrumentHandle,
                                          ViInt32 *sequenceRepetition);

ViStatus _VI_FUNC gmpsp_SetSeqDefaultTime (ViSession instrumentHandle,
                                           ViReal64 defaultTime);

ViStatus _VI_FUNC gmpsp_GetSeqDefaultTime (ViSession instrumentHandle,
                                           ViReal64 *defaultTime);

ViStatus _VI_FUNC gmpsp_actSendSeqTrigger (ViSession instrumentHandle,
                                           ViInt32 sequenceControl);

ViStatus _VI_FUNC gmpsp_actSeqStatus (ViSession instrumentHandle,
                                      ViInt32 *sequenceStatus,
                                      ViInt32 *sequenceNumber,
                                      ViInt32 *repetition, ViInt32 *step);

ViStatus _VI_FUNC gmpsp_resetMinMax (ViSession instrumentHandle);

ViStatus _VI_FUNC gmpsp_actProtectionStatus (ViSession instrumentHandle,
                                             ViBoolean *OVPStatus,
                                             ViBoolean *OCPStatus);

ViStatus _VI_FUNC gmpsp_fetchMinMax (ViSession instrumentHandle,
                                     ViReal64 *minVoltage_inV,
                                     ViReal64 *maxVoltage_inV,
                                     ViReal64 *minCurrent_inA,
                                     ViReal64 *maxCurrent_inA);

ViStatus _VI_FUNC gmpsp_measOutVolt (ViSession instrumentHandle,
                                     ViReal64 *outputVoltage);

ViStatus _VI_FUNC gmpsp_measOutCurr (ViSession instrumentHandle,
                                     ViReal64 *outputCurrent);

ViStatus _VI_FUNC gmpsp_measOutPower (ViSession instrumentHandle,
                                      ViReal64 *outputPower_inW);

ViStatus _VI_FUNC gmpsp_errorCheckState (ViSession instrumentHandle,
                                         ViBoolean stateChecking);

ViStatus _VI_FUNC gmpsp_SetStatusRegister (ViSession instrumentHandle,
                                           ViInt32 reg, ViInt32 enable);

ViStatus _VI_FUNC gmpsp_getStatusRegister (ViSession instrumentHandle,
                                           ViInt32 statusRegistersQuery,
                                           ViInt32 *registerValue);

ViStatus _VI_FUNC gmpsp_SaveSetup (ViSession instrumentHandle, ViInt32 userSetup);

ViStatus _VI_FUNC gmpsp_RecallSetup (ViSession instrumentHandle,
                                     ViInt32 setupNumber);

ViStatus _VI_FUNC gmpsp_writeInstrData (ViSession instrumentHandle,
                                        ViChar writeBuffer[]);

ViStatus _VI_FUNC gmpsp_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar readBuffer[],
                                       ViInt32 *numBytesRead);

ViStatus _VI_FUNC gmpsp_reset (ViSession instrumentHandle);

ViStatus _VI_FUNC gmpsp_self_test (ViSession instrumentHandle,
                                   ViInt16 *selfTestResult,
                                   ViChar selfTestMessage[]);

ViStatus _VI_FUNC gmpsp_error_query (ViSession instrumentHandle,
                                     ViInt32 *errorCode, ViChar errorMessage[]);

ViStatus _VI_FUNC gmpsp_error_message (ViSession instrumentHandle,
                                       ViStatus statusCode, ViChar message[]);

ViStatus _VI_FUNC gmpsp_revision_query (ViSession instrumentHandle,
                                        ViChar instrumentDriverRevision[],
                                        ViChar firmwareRevision[]);

ViStatus _VI_FUNC gmpsp_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
